
{.$define Debug}

program Solution;
{$M 64000,0,0}

{$ifndef Debug}
{$A+,B-,D+,E+,F-,G+,I+,L+,N+,O-,P-,Q-,R-,S-,T-,V-,X+,Y+}
const
  inFile			= 'input.txt';
  outFile			= 'output.txt';
{$else}
{$A+,B-,D+,E+,F-,G+,I+,L+,N+,O-,P-,Q+,R+,S+,T-,V-,X+,Y+}
const
  inFile			= 'input.txt';
  outFile			= 'con';
  dbgFile			= 'con';
var
  dbg                           : Text;
{$endif}

const
  maxN                          = 100;
  eps                           = 1e-6;

type
  TSet                          = set of 1..maxN;
  int                           = longint;

  TRect                         = record
    h,w                         : int;
  end;

  float                         = extended;

var
  m                             : integer;
  n                             : integer;
  a                             : array[1..maxN] of TRect;
  b                             : array[1..maxN] of TRect;
  g                             : array[1..maxN] of TSet;
  p                             : array[1..maxN] of integer;
  visited                       : array[1..maxN] of boolean;

procedure Swap( var a, b : int );
var
  c                             : int;

begin
  c := a;
  a := b;
  b := c;
end;

function Contains( var a, b : TRect ) : boolean;
var
  c                             : int;

  function Try : boolean;
  var
    alpha,beta                  : float;
    p,q,r                       : float;
    d                           : float;

  begin
    Try := true;
    if (a.w >= b.w) and (a.h >= b.h) then exit;
    Try := false;
    p := 1 + sqr( b.w / b.h );
    q := - 2 * a.w * b.w / b.h;
    r := sqr( a.w * 1.0 ) - sqr( b.h * 1.0 );
    d := sqr( q ) - 4 * p * r;
    if abs( d ) < eps then d := 0;
    if d < -eps then exit;
    beta := ( - q + sqrt( d ) ) / ( 2 * p );
    alpha := (a.w - beta * b.w / b.h) * b.w / b.h;
    if (alpha > -eps) and (beta > -eps) and
       (alpha + beta < a.h + eps) then Try := true;
  end;

begin
  Contains := true;
  if Try then exit;
  Swap( a.w, a.h );
  if Try then exit;
  Swap( b.h, b.w );
  if Try then exit;
  Swap( a.w, a.h );
  if Try then exit;
  Contains := false;
end;

procedure BuildGraph;
var
  i,j                           : integer;

begin
  fillchar( g, sizeof(g), false );
  for i := 1 to n do
    for j := 1 to m do
      if Contains( b[j], a[i] ) then include( g[i], j );
end;

function Try( k : integer ) : boolean;
var
  i                             : integer;

begin
  Try := false;
  if visited[k] then exit;
  visited[k] := true;
  for i := 1 to n do
    if (k in g[i]) and ((p[i] = 0) or Try( p[i] )) then begin
      p[i] := k;
      Try := true;
      exit;
    end;
end;

procedure Solve;
var
  j                             : integer;

begin
  BuildGraph;
  fillchar( p, sizeof(p), 0 );
  for j := 1 to m do begin
    fillchar( visited, sizeof(visited), false );
    Try( j );
  end;
end;

procedure ReadData;
var
  i				: integer;

begin
  read( m, n );
  for i := 1 to m do read( b[i].w, b[i].h );
  for i := 1 to n do read( a[i].w, a[i].h );
end;

procedure WriteData;
var
  i,j				: integer;

begin
  j := 0;
  for i := 1 to n do
    if p[i] <> 0 then inc( j );
  writeln( j );
  for i := 1 to n do
    if p[i] <> 0 then writeln( i, ' ', p[i] );
end;

procedure Initialize;
begin

  assign( input, inFile );
  reset( input );

  assign( output, outFile );
  rewrite( output );

  {$ifdef Debug}
  assign( dbg, dbgFile );
  rewrite( dbg );
  writeln( '----Initialized----' );
  {$endif}

end;

procedure Finalize;
begin

  {$ifdef Debug}
  close( dbg );
  writeln( '----Finalized----' );
  {$endif}

  close( input );
  close( output );
  halt( 0 );

end;

begin
  Initialize;
  ReadData;
  Solve;
  WriteData;
  Finalize;
end.